# Bachelor's thesis

## Voxelizer: an Open Source Voxelization Engine

This archive contains the software repositories developed in connection with the thesis: "Voxelizer: an Open Source Voxelization Engine". All top-level folders contains a **git** repository.

For descriptions and installation instruction for the different projects, se below.

## Table of Contents
  - [Development Setup](#development-setup)
  - [3D model](#3d-model)
  - [Voxelizer](#voxelizer)
  - [Voxelizer Desktop](#voxelizer-desktop)
  - [three-voxel-loader](#three-voxel-loader)
  - [BINVOX](#binvox)
  - [JSDoc Action](#jsdoc-action)
  - [File Existence action](#file-existence-action)
  - [File Reader action](#file-reader-action)

## Development Setup
These instructions assumes that [Node.js](https://nodejs.org/en/) version 8 or newer is correctly installed.

All the repositories can be set up by running the following simple command:
```bash
$ npm install
```
inside the relevant `repository` folder.

For example: to setup the Voxelizer engine for development, simply `cd` into the `voxelizer` folder provided with this archive, and run `$ npm install`. All dependencies will then be automatically installed and the application correctly configured.

## 3D model
A 3D model is supplied for testing the different software.
This is a textured anvil. The file type is `glb`, and the file is located in the root directory of this archive. It is named `anvil.gbl`.

## Voxelizer
Voxelizer is a JavaScript voxelization engine for conducting voxelization of 3D models.

> GitHub: https://github.com/andstor/voxelizer

> npm: https://www.npmjs.com/package/voxelizer

Consult the [README.md](voxelizer/README.md) file inside the `voxelizer` repository for installation and usage details.

The old version of the engine is accessible through checking out the git tag: "v0.1.3".
It is also available on GitHub: https://github.com/andstor/voxelizer/tree/v0.1.3

Do note that there is an live example of the engine available at: https://andstor.github.io/voxelizer/examples/

## Voxelizer Desktop
The Voxelizer Desktop is a desktop application for easy 3D model voxelization.

> GitHub: https://github.com/andstor/voxelizer-desktop

Consult the [README.md](voxelizer-desktop/README.md) file inside the `voxelizer-desktop` repository for installation and development instructions.

Precompiled installation files for Windows, Linux and macOS are also provided, located under `voxelizer-desktop/dist`. These can also be found on GitHub at: https://github.com/andstor/voxelizer-desktop/releases

## three-voxel-loader
The three-voxel-loader is a three.js plugin for loading voxel data.

> GitHub: https://github.com/andstor/three-voxel-loader

> npm: https://www.npmjs.com/package/three-voxel-loader

Consult the [README.md](three-voxel-loader/README.md) file inside the `three-voxel-loader` repository for installation and usage instructions.

Do note that there is an live example of the plugin available at: https://andstor.github.io/three-voxel-loader/examples/

## BINVOX
The BINVOX package is a parser and builder for BINVOX voxel file format

> GitHub: https://github.com/andstor/binvox

Consult the [README.md](binvox/README.md) file inside the `binvox` repository for installation and usage instructions.

## JSDoc Action
The JSDoc Action is a GitHub Action to build JSDoc documentation.

> GitHub: https://github.com/andstor/jsdoc-action

> Github Marketplace: https://github.com/marketplace/actions/jsdoc-action

Consult the [README.md](jsdoc-action/README.md) file inside the `jsdoc-action` repository for installation and usage instructions.

## File Existence action
The File Reader action is a GitHub Action to read the contents of a file.

> GitHub: https://github.com/andstor/file-existence-action

> Github Marketplace: https://github.com/marketplace/actions/file-existence

Consult the [README.md](file-existence-action/README.md) file inside the `file-existence-action` repository for installation and usage instructions.

## File Reader action
The File Reader action is a GitHub Action to read the contents of a file.

> GitHub: https://github.com/andstor/file-reader-action

> Github Marketplace: https://github.com/marketplace/actions/file-reader

Consult the [README.md](file-reader-action/README.md) file inside the `file-reader-action` repository for installation and usage instructions.
